@@ -2,7 +2,7 @@
 
 #
 # dbjoin.pm
-# Copyright (C) 1991-2018 by John Heidemann <johnh@isi.edu>
+# Copyright (C) 1991-2022 by John Heidemann <johnh@isi.edu>
 #
 # This program is distributed under terms of the GNU general
 # public license, version 2.  See the file COPYING
@@ -328,6 +328,7 @@ sub parse_options ($@) {
 	'N|lexical' => sub { $self->parse_sort_option(@_); },
 	'r|descending' => sub { $self->parse_sort_option(@_); },
 	'R|ascending' => sub { $self->parse_sort_option(@_); },
+	'type-inferred-sorting' => sub { $self->parse_sort_option(@_); },
 	'<>' => sub { $self->parse_sort_option('<>', @_); },
 	) or pod2usage(2);
     croak($self->{_prog} . ": internal error, extra arguments.\n")
@@ -576,14 +577,16 @@ sub run_merge_join($) {
 	$prev_frefs[0] = $frefs[0];
 	$frefs[0] = &{$fastpath_subs[0]}();
 	if (defined($frefs[0])) {
-	    &{$check_compare_subs[0]}() <= 0 or croak("dbjoin: left stream is unsorted.\n");
+	    &{$check_compare_subs[0]}() <= 0 or 
+                croak("dbjoin: left stream is unsorted, compare:\n" . "\t" . join(" ", @{$prev_frefs[0]}) . "\n\t" . join(" ", @{$frefs[0]}) . "\n");
 	};
     };
     my $advance_right = sub {
 	$prev_frefs[1] = $frefs[1];
 	$frefs[1] = &{$fastpath_subs[1]}();
 	if (defined($frefs[1])) {
-	    &{$check_compare_subs[1]}() <= 0 or croak("dbjoin: right stream is unsorted.\n");
+	    &{$check_compare_subs[1]}() <= 0 or
+                croak("dbjoin: right stream is unsorted, compare:\n" . "\t" . join(" ", @{$prev_frefs[1]}) . "\n\t" . join(" ", @{$frefs[1]}) . "\n");
 	};
     };
 
@@ -747,14 +750,14 @@ sub run_hash_join($$$) {
     # Build phase:
     #
     # Load the hashed table into memory,
-    # building a hash table %h.
+    # building a hash table %hashed_table.
     #
     # Probe phase:
     #
     # Then walk the larger table,
     # checking against the hash table for matches.
     #
-    # We currently require it fit in memory.
+    # We currently require that it fits in memory.
     #
 
     #
@@ -782,11 +785,21 @@ sub run_hash_join($$$) {
     $@ && croak($self->{_prog} . ":  internal eval error in hash build code: $@.\n$code\n");
 
     while ($fref = &{$fastpath_subs[$hashside]}()) {
+        #
 	# build the hash entry
+        #
+        # Note that each entry in %hashed_table is either an ARRAY,
+        # in which case it is the ONE hit.
+        # Or it's a SCALAR (ref == ''), in which case
+        # there is an array of matchines in $hashed_table_overflow{$key}.
+        #
+        # This two-level structure avoids building arrays of arrays
+        # in the common case of one reference for each element.
+        #
 	my($key, $aref) = &{$build_key_from_hashside}($fref);
 	if (defined($hashed_table{$key})) {
-	    # overflow
-	    if (ref($hashed_table{$key}) eq 'SCALAR') {
+	    # overflow?
+	    if (ref($hashed_table{$key}) eq '') {
 		# already overflowed
 		push(@{$hashed_table_overflow{$key}}, $aref);
 	    } else {
@@ -818,6 +831,7 @@ sub run_hash_join($$$) {
     $code = '$build_output_from_full = sub {' . "\n" . $reset_output_code . $self->{_build_output_from_full_code} . "\n};\n" .
 	    '$build_output_from_hit = sub {' . "\n" . $reset_output_code . $self->{_build_output_from_hit_code} . "\n};\n" .
 	    '$merge_output_from_hit = sub {' . "\n" . $self->{_merge_output_from_hit_code} . "\n};\n";
+    print "CODE in run_hash_join:\n$code\n" if ($self->{_debug} > 1);
     eval $code;
     $@ && croak($self->{_prog} . ":  internal eval error in hash probe code: $@.\n$code\n");
 
@@ -902,7 +916,7 @@ sub run($) {
 
 =head1 AUTHOR and COPYRIGHT
 
-Copyright (C) 1991-2018 by John Heidemann <johnh@isi.edu>
+Copyright (C) 1991-2022 by John Heidemann <johnh@isi.edu>
 
 This program is distributed under terms of the GNU general
 public license, version 2.  See the file COPYING
